@@ -128,7 +128,7 @@ class DynamicSetting(object):
             self.download()
 
     def load_from_cache(self, version):
-        print(f'{self.instance_id}: load from cache')
+
         try:
             data = self.redis_client.get_latest_data(
                 keys=[
@@ -158,7 +158,7 @@ class DynamicSetting(object):
         self.download()
 
     def load_from_file(self):
-        print(f'{self.instance_id}: load from file')
+
         self.logger.warning('Loading settings from file')
         latest_files = [fn for fn in [self.parse_filename(filename) for filename in os.listdir(self.data_dir)
                                       if filename.endswith('.json') and filename.startswith(self.slug)
@@ -194,7 +194,7 @@ class DynamicSetting(object):
         return self.parse_data(data=data)
 
     def load_fallback(self):
-        print(f'{self.instance_id}: load fallback')
+
         self.load_content(data=self.fallback_data,
                           version=self.fallback_version,
                           download_time=None,
